netapp_ontap.models.kerberos_realm_kdc API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.kerberos_realm_kdc`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class KerberosRealmKdcSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the KerberosRealmKdc object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `ip GET POST PATCH`

    KDC IP address

    Example: 1.2.3.4

  `port GET POST PATCH`

    KDC port

    Example: 88

  `vendor GET POST PATCH`

    Key Distribution Center (KDC) vendor. Following values are suported:

    - microsoft - Microsoft Active Directory KDC
    - other - MIT Kerberos KDC or other KDC

    Valid choices:

    - microsoft
    - other